*** Settings ***
Documentation     客户端-获取所有职称
Suite Setup       get_login_token    ${URL}
Library           Collections
Library           HttpLibrary.HTTP
Library           RequestsLibrary

*** Variables ***
${method}         GetAllRanksAsync
${uri}            /IRankService

*** Test Cases ***
Class_001_获取所有职称，单个组织、包含职称
    [Template]    getAllRanks_assertClass
    ${token}    Organization_2022031612051511AJL8

Class_002_获取所有职称，多个组织、包含职称
    [Template]    getAllRanks_assertClass
    ${token}    Organization_2022031612051511AJL8|Organization_20220316112911z3Fv8H

Class_003_获取所有职称，单个组织、不包含职称
    [Template]    getAllRanks_assertClassNull
    ${token}    Organization_202203020833096S18eE

Class_004_获取所有职称，多个组织、不包含职称
    [Template]    getAllRanks_assertClassNull
    ${token}    Organization_20220302075923FcyxLj|Organization_20220302080016510cQE|Organization_2022030208285601NQCo

Class_005_获取所有职称，不填写组织
    [Template]    getAllRanks_assertClass
    ${token}    ${EMPTY}

Exception_001_获取所有职称，Token非空校验
    [Template]    getAllRanks_assertException
    ${EMPTY}    Organization_20220302075923FcyxLj|Organization_20220302080016510cQE|Organization_2022030208285601NQCo    1002    Permission validation error

Exception_002_获取所有职称，Token正确性校验
    [Template]    getAllRanks_assertException
    ${EMPTY}    Organization_20220302075923FcyxLj|Organization_20220302080016510cQE|Organization_2022030208285601NQCo    1002    Permission validation error

*** Keywords ***
getAllRanks_Post
    [Arguments]    ${token}    ${organizationCodes}
    ${params}    Create List
    ${param}    Create Dictionary
    Set To Dictionary    ${param}    Token=${token}
    Set To Dictionary    ${param}    OrganizationCodes=${organizationCodes}
    Append To List    ${params}    ${param}
    ${data}    common_data    ${method}    ${params}
    Log    ${data}
    Log    ---开始断言验证---
    ${response}    request_post    ${URL}    ${uri}    ${data}
    Log    ${response}
    log    ${response.content}
    ${content}    Set Variable    ${response.content}
    Log    ---输出返回内容---：
    Log Json    ${content}    INFO
    Log    ---开始断言验证---
    Should Be True    ${response.status_code}==200
    [Return]    ${response}

getAllRanks_assertClass
    [Arguments]    ${token}    ${organizationCode}
    ${organizationCodes}    String.Split String    ${organizationCode}    |
    #${rankCodes}    String.Split String    ${rankCode}
    #${rankCodes}    String.Split String    ${rankCode}    |
    Log    ${organizationCodes}
    #Log    ${rankCodes}
    ${content}    getAllRanks_Post    ${token}    ${organizationCodes}
    ${result}    Get From Dictionary    ${content.json()}    result
    Log    ${result}
    ${length}    Get Length    ${result}
    Run Keyword If    ${length}>0    Should Contain    ${result}[0]    RankCode
    Should Contain    ${result}[0]    RankName
    ...    ELSE    Log    do not contain RankName
    [Return]    ${content}

getAllRanks_assertClassNull
    [Arguments]    ${token}    ${organizationCode}
    ${organizationCodes}    String.Split String    ${organizationCode}    |
    #${rankCodes}    String.Split String    ${rankCode}
    #${rankCodes}    String.Split String    ${rankCode}    |
    Log    ${organizationCodes}
    #Log    ${rankCodes}
    ${content}    getAllRanks_Post    ${token}    ${organizationCodes}
    ${result}    Get From Dictionary    ${content.json()}    result
    Should Be Empty    ${result}
    [Return]    ${content}

getAllRanks_assertException
    [Arguments]    ${token}    ${organizationCode}    ${error_code}    ${error_msg}
    ${organizationCodes}    String.Split String    ${organizationCode}    |
    #${rankCodes}    String.Split String    ${rankCode}
    #${rankCodes}    String.Split String    ${rankCode}    |
    Log    ${organizationCodes}
    #Log    ${rankCodes}
    ${content}    getAllRanks_Post    ${token}    ${organizationCodes}
    ${error}    Get From Dictionary    ${content.json()}    error
    ${code}    Get From Dictionary    ${error}    code
    ${message}    Get From Dictionary    ${error}    message
    Should Be Equal As Numbers    ${code}    ${error_code}
    Should Be String    ${message}    ${error_msg}
    [Return]    ${content}
