*** Settings ***
Documentation     客户端-根据编码获取职称信息
Suite Setup       get_login_token    ${URL}
Test Setup
Library           Collections
Library           HttpLibrary.HTTP
Library           RequestsLibrary

*** Variables ***
${uri}            /IRankService
${method}         GetRankByCodeAsync

*** Test Cases ***
Class_001_根据编码获取职称信息，包含职称
    [Template]    getRankByCode_assertClass
    ${token}    UserRankDO_20220316115514V07f63

Class_002_根据编码获取职称信息，不包含职称
    [Template]    getRankByCode_assertClassNull
    ${token}    Organization_202203020833096S18eE

Exception_001_根据编码获取职称信息，Token正确性校验
    [Template]    getRankByCode_assertException
    11111    UserRankDO_20220126135848Kk4as7    1002    Permission validation error

Exception_002_根据编码获取职称信息，Token非空校验
    [Template]    getRankByCode_assertException
    ${EMPTY}    UserRankDO_20220126135848Kk4as7    1002    Permission validation error

Exception_003_根据编码获取职称信息，RankCode非空校验
    [Template]    getRankByCode_assertException
    ${token}    ${EMPTY}    1001    Code can't be null

*** Keywords ***
getRankByCode_Post
    [Arguments]    ${token}    ${rankcode}
    ${params}    Create Dictionary
    Set To Dictionary    ${params}    Token=${token}
    Set To Dictionary    ${params}    RankCode=${rankcode}
    ${data}    common_data    ${method}    ${params}
    Log    ${data}
    Log    ---开始断言验证---
    ${response}    request_post    ${URL}    ${uri}    ${data}
    Log    ${response}
    log    ${response.content}
    ${content}    Set Variable    ${response.content}
    Log    ---输出返回内容---：
    Log Json    ${content}    INFO
    Log    ---开始断言验证---
    Should Be True    ${response.status_code}==200
    [Return]    ${response}

getRankByCode_assertClass
    [Arguments]    ${token}    ${rankcode}
    ${content}    getRankByCode_Post    ${token}    ${rankcode}
    ${result}    Get From Dictionary    ${content.json()}    result
    ${rankCode}    Get From Dictionary    ${result}    RankCode
    ${rankName}    Get From Dictionary    ${result}    RankName
    Should Not Be Empty    ${rankCode}
    Should Not Be Empty    ${rankName}
    [Return]    ${content}

getRankByCode_assertException
    [Arguments]    ${token}    ${rankcode}    ${error_code}    ${error_msg}
    ${content}    getRankByCode_Post    ${token}    ${rankcode}
    ${error}    Get From Dictionary    ${content.json()}    error
    ${code}    Get From Dictionary    ${error}    code
    ${message}    Get From Dictionary    ${error}    message
    Should Be Equal As Numbers    ${code}    ${error_code}
    Should Be String    ${message}    ${error_msg}
    [Return]    ${content}

getRankByCode_assertClassNull
    [Arguments]    ${token}    ${rankcode}
    ${content}    getRankByCode_Post    ${token}    ${rankcode}
    ${result}    Get From Dictionary    ${content.json()}    result
    Log    ${result}
    run keyword if    ${result}==${null}    Log    result is null
    [Return]    ${content}
