*** Settings ***
Documentation     客户端-搜索组织
Suite Setup       get_login_token    ${URL}    jo22
Library           Collections
Library           HttpLibrary.HTTP
Library           RequestsLibrary

*** Variables ***
${method}         SearchOrganizationsAsync
${uri}            /IOrganizationService

*** Test Cases ***
Class_001_获取组织信息，组织类型为医院
    [Template]    searchOrganizations_assertClass
    ${token}    ${EMPTY}    ${EMPTY}    "0"

Class_002_获取组织信息，组织类型为部门
    [Template]    searchOrganizations_assertClass
    ${token}    ${EMPTY}    ${EMPTY}    "1"

Class_003_获取组织信息，组织类型为科室
    [Template]    searchOrganizations_assertNull
    ${token}    ${EMPTY}    ${EMPTY}    "2"

Class_004_获取组织信息，填写OrganizationName中包含的关键字
    [Template]    searchOrganizations_assertClass
    ${token}    医院    ${EMPTY}    "0"

Class_005_获取组织信息，填写OrganizationName中不包含的关键字
    [Template]    searchOrganizations_assertNull
    ${token}    哈哈哈哈哈哈哈哈&*&*（（    ${EMPTY}    "0"

Class_006_获取组织信息，填写存在下级部门的父级编码
    [Template]    searchOrganizations_assertClass
    ${token}    ${EMPTY}    Organization_20220402033149q92esc    "0"

Class_007_获取组织信息，填写不存在下级部门的父级编码
    [Template]    searchOrganizations_assertNull
    ${token}    ${EMPTY}    123456789    "0"

Class_008_获取组织信息，填写不存的组织类型
    [Template]    searchOrganizations_assertNull
    ${token}    ${EMPTY}    ${EMPTY}    "999999"

Exception_001_搜索组织，Token非空校验
    [Template]    searchOrganizations_assertException
    ${EMPTY}    ${EMPTY}    ${EMPTY}    "0"    1002    Permission validation error

Exception_002_搜索组织，Token正确性校验
    [Template]    searchOrganizations_assertException
    1234567890    ${EMPTY}    ${EMPTY}    "0"    1002    Permission validation error

*** Keywords ***
searchOrganizations_Post
    [Arguments]    ${token}    ${keyword}    ${parentCode}    ${organizationType}
    ${params}    Create List
    ${param}    Create Dictionary
    Set To Dictionary    ${param}    Token=${token}
    Set To Dictionary    ${param}    Keyword=${keyword}
    Set To Dictionary    ${param}    ParentCode=${parentCode}
    ${type}    Remove String    ${organizationType}    "
    ${organizationType11}    Convert To Integer    ${type}
    Set To Dictionary    ${param}    OrganizationType=${organizationType11}
    Append To List    ${params}    ${param}
    ${data}    common_data    ${method}    ${params}
    Log    ${data}
    Log    ---开始断言验证---
    ${response}    request_post    ${URL}    ${uri}    ${data}
    Log    ${response}
    log    ${response.content}
    ${content}    Set Variable    ${response.content}
    Log    ---输出返回内容---：
    Log Json    ${content}    INFO
    Log    ---开始断言验证---
    Should Be True    ${response.status_code}==200
    [Return]    ${response}

searchOrganizations_assertClass
    [Arguments]    ${token}    ${keyword}    ${parentCode}    ${organizationType}
    ${content}    searchOrganizations_Post    ${token}    ${keyword}    ${parentCode}    ${organizationType}
    ${result}    Get From Dictionary    ${content.json()}    result
    ${length}    Get Length    ${result}
    Run Keyword If    ${length}>0    Should Contain    ${result}[0]    OrganizationCode
    Should Contain    ${result}[0]    OrganizationName
    ...    ELSE    Log    do not contain OrganizationName
    [Return]    ${content}

searchOrganizations_assertException
    [Arguments]    ${token}    ${keyword}    ${parentCode}    ${organizationType}    ${error_code}    ${error_msg}
    ${content}    searchOrganizations_Post    ${token}    ${keyword}    ${parentCode}    ${organizationType}
    ${error}    Get From Dictionary    ${content.json()}    error
    ${code}    Get From Dictionary    ${error}    code
    ${message}    Get From Dictionary    ${error}    message
    Should Be Equal As Numbers    ${code}    ${error_code}
    Should Be String    ${message}    ${error_msg}
    [Return]    ${content}

searchOrganizations_assertNull
    [Arguments]    ${token}    ${keyword}    ${parentCode}    ${organizationType}
    ${content}    searchOrganizations_Post    ${token}    ${keyword}    ${parentCode}    ${organizationType}
    ${result}    Get From Dictionary    ${content.json()}    result
    should be empty    ${result}
    [Return]    ${content}
